==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/GridColumnOptionsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
/**
 * @hidden
 */
var GridColumnOptionsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnOptionsBaseDescriptionMetadata, _super);
    function GridColumnOptionsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsBaseDescriptionMetadata.b = function (a) {
        if (GridColumnOptionsBaseDescriptionMetadata.a == null) {
            GridColumnOptionsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnOptionsBaseDescriptionMetadata.c(GridColumnOptionsBaseDescriptionMetadata.a);
        }
        if (a.k(GridColumnOptionsBaseDescriptionMetadata.a)) {
            return;
        }
        a.ab(GridColumnOptionsBaseDescriptionMetadata.a);
        DataGridColumnDescriptionMetadata.d(a);
    };
    GridColumnOptionsBaseDescriptionMetadata.c = function (a) {
        a.item("AutoSize", "Boolean");
        a.item("BackgroundColor", "Brush");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight;SlingshotLight;SlingshotDark;RevealLight;RevealDark");
        a.item("ActualBaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("ActualBaseTheme@names", "Default;DenaliLight;MaterialLight;SlingshotLight;SlingshotDark;RevealLight;RevealDark");
        a.item("ButtonDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ButtonDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualButtonDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualButtonDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ButtonFontFamily", "(w:ButtonFontFamily/FontFamilyTransform,xam:ButtonFontFamily,wf:ButtonFontFamily,web:buttonTextStyle/FontFamilyTransform)String");
        a.item("ButtonFontSize", "(w:ButtonFontSize,xam:ButtonFontSize,wf:ButtonFontSize,web:buttonTextStyle/FontSizeTransform)Number:double");
        a.item("ButtonFontStyle", "(w:ButtonFontStyle/FontStyleTransform,xam:ButtonFontFamily/FontStyleTransform,wf:ButtonFontFamily/FontStyleTransform,web:buttonTextStyle/FontStyleTransform)String");
        a.item("ButtonFontWeight", "(w:ButtonFontWeight/FontWeightTransform,xam:ButtonFontFamily/FontWeightTransform,wf:ButtonFontFamily/FontWeightTransform,web:buttonTextStyle/FontWeightTransform)String");
        a.item("Column", "ExportedType:DataGridColumn");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("LabelFontFamily", "(w:LabelFontFamily/FontFamilyTransform,xam:LabelFontFamily,wf:LabelFontFamily,web:labelTextStyle/FontFamilyTransform)String");
        a.item("LabelFontSize", "(w:LabelFontSize,xam:LabelFontSize,wf:LabelFontSize,web:labelTextStyle/FontSizeTransform)Number:double");
        a.item("LabelFontStyle", "(w:LabelFontStyle/FontStyleTransform,xam:LabelFontFamily/FontStyleTransform,wf:LabelFontFamily/FontStyleTransform,web:labelTextStyle/FontStyleTransform)String");
        a.item("LabelFontWeight", "(w:LabelFontWeight/FontWeightTransform,xam:LabelFontFamily/FontWeightTransform,wf:LabelFontFamily/FontWeightTransform,web:labelTextStyle/FontWeightTransform)String");
        a.item("TextColor", "Brush");
    };
    GridColumnOptionsBaseDescriptionMetadata.d = function (a) {
        GridColumnOptionsBaseDescriptionMetadata.b(a);
        a.ac("GridColumnOptionsBase", GridColumnOptionsBaseDescriptionMetadata.a);
    };
    GridColumnOptionsBaseDescriptionMetadata.$t = markType(GridColumnOptionsBaseDescriptionMetadata, 'GridColumnOptionsBaseDescriptionMetadata');
    GridColumnOptionsBaseDescriptionMetadata.a = null;
    return GridColumnOptionsBaseDescriptionMetadata;
}(Base));
export { GridColumnOptionsBaseDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/GridColumnOptionsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
/**
 * @hidden
 */
var GridColumnOptionsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnOptionsBaseDescriptionMetadata, _super);
    function GridColumnOptionsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsBaseDescriptionMetadata.b = function (a) {
        if (GridColumnOptionsBaseDescriptionMetadata.a == null) {
            GridColumnOptionsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnOptionsBaseDescriptionMetadata.c(GridColumnOptionsBaseDescriptionMetadata.a);
        }
        if (a.k(GridColumnOptionsBaseDescriptionMetadata.a)) {
            return;
        }
        a.ac(GridColumnOptionsBaseDescriptionMetadata.a);
        DataGridColumnDescriptionMetadata.d(a);
    };
    GridColumnOptionsBaseDescriptionMetadata.c = function (a) {
        a.item("AutoSize", "Boolean");
        a.item("BackgroundColor", "Brush");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight;SlingshotLight;SlingshotDark;RevealLight;RevealDark");
        a.item("ActualBaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("ActualBaseTheme@names", "Default;DenaliLight;MaterialLight;SlingshotLight;SlingshotDark;RevealLight;RevealDark");
        a.item("ButtonDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ButtonDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualButtonDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualButtonDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ButtonFontFamily", "(w:ButtonFontFamily/FontFamilyTransform,xam:ButtonFontFamily,wf:ButtonFontFamily,web:buttonTextStyle/FontFamilyTransform)String");
        a.item("ButtonFontSize", "(w:ButtonFontSize,xam:ButtonFontSize,wf:ButtonFontSize,web:buttonTextStyle/FontSizeTransform)Number:double");
        a.item("ButtonFontStyle", "(w:ButtonFontStyle/FontStyleTransform,xam:ButtonFontFamily/FontStyleTransform,wf:ButtonFontFamily/FontStyleTransform,web:buttonTextStyle/FontStyleTransform)String");
        a.item("ButtonFontWeight", "(w:ButtonFontWeight/FontWeightTransform,xam:ButtonFontFamily/FontWeightTransform,wf:ButtonFontFamily/FontWeightTransform,web:buttonTextStyle/FontWeightTransform)String");
        a.item("Column", "ExportedType:DataGridColumn");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("LabelFontFamily", "(w:LabelFontFamily/FontFamilyTransform,xam:LabelFontFamily,wf:LabelFontFamily,web:labelTextStyle/FontFamilyTransform)String");
        a.item("LabelFontSize", "(w:LabelFontSize,xam:LabelFontSize,wf:LabelFontSize,web:labelTextStyle/FontSizeTransform)Number:double");
        a.item("LabelFontStyle", "(w:LabelFontStyle/FontStyleTransform,xam:LabelFontFamily/FontStyleTransform,wf:LabelFontFamily/FontStyleTransform,web:labelTextStyle/FontStyleTransform)String");
        a.item("LabelFontWeight", "(w:LabelFontWeight/FontWeightTransform,xam:LabelFontFamily/FontWeightTransform,wf:LabelFontFamily/FontWeightTransform,web:labelTextStyle/FontWeightTransform)String");
        a.item("TextColor", "Brush");
    };
    GridColumnOptionsBaseDescriptionMetadata.d = function (a) {
        GridColumnOptionsBaseDescriptionMetadata.b(a);
        a.ad("GridColumnOptionsBase", GridColumnOptionsBaseDescriptionMetadata.a);
    };
    GridColumnOptionsBaseDescriptionMetadata.$t = markType(GridColumnOptionsBaseDescriptionMetadata, 'GridColumnOptionsBaseDescriptionMetadata');
    GridColumnOptionsBaseDescriptionMetadata.a = null;
    return GridColumnOptionsBaseDescriptionMetadata;
}(Base));
export { GridColumnOptionsBaseDescriptionMetadata };
